==> qtjambi-qt3drender-5.15.13-sources.jar: io/qt/qt3d/render/QPickLineEvent.java <==
package io.qt.qt3d.render;


/**
 * <p>Holds information when a segment of a line is picked</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qpicklineevent.html">Qt3DRender::QPickLineEvent</a></p>
 */
public class QPickLineEvent extends io.qt.qt3d.render.QPickEvent
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QPickLineEvent.class);
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qpicklineevent.html#QPickLineEvent">Qt3DRender::QPickLineEvent::QPickLineEvent()</a></p>
     */
    public QPickLineEvent(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QPickLineEvent instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qpicklineevent.html#QPickLineEvent">Qt3DRender::QPickLineEvent::QPickLineEvent(QPointF,QVector3D,QVector3D,float,uint,uint,uint,Buttons,int,int)</a></p>
     */
    public QPickLineEvent(io.qt.core.QPointF position, io.qt.gui.QVector3D worldIntersection, io.qt.gui.QVector3D localIntersection, float distance, int edgeIndex, int vertex1Index, int vertex2Index, io.qt.qt3d.render.QPickEvent.Buttons button, int buttons, int modifiers){
        super((QPrivateConstructor)null);
        initialize_native(this, position, worldIntersection, localIntersection, distance, edgeIndex, vertex1Index, vertex2Index, button, buttons, modifiers);
    }
    
    private native static void initialize_native(QPickLineEvent instance, io.qt.core.QPointF position, io.qt.gui.QVector3D worldIntersection, io.qt.gui.QVector3D localIntersection, float distance, int edgeIndex, int vertex1Index, int vertex2Index, io.qt.qt3d.render.QPickEvent.Buttons button, int buttons, int modifiers);
    
    /**
     * <p>QPickLineEvent::edgeIndex Returns the index of the picked edge</p>
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qpicklineevent.html#edgeIndex">Qt3DRender::QPickLineEvent::edgeIndex()const</a></p>
     */
    @io.qt.QtPropertyReader(name="edgeIndex")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final int edgeIndex(){
        return edgeIndex_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int edgeIndex_native_constfct(long __this__nativeId);
    
    /**
     * <p>QPickLineEvent::vertex1Index Returns the index of the first point of the picked edge</p>
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qpicklineevent.html#vertex1Index">Qt3DRender::QPickLineEvent::vertex1Index()const</a></p>
     */
    @io.qt.QtPropertyReader(name="vertex1Index")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final int vertex1Index(){
        return vertex1Index_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int vertex1Index_native_constfct(long __this__nativeId);
    
    /**
     * <p>QPickLineEvent::vertex2Index Returns the index of the second point of the picked triangle</p>
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qpicklineevent.html#vertex2Index">Qt3DRender::QPickLineEvent::vertex2Index()const</a></p>
     */
    @io.qt.QtPropertyReader(name="vertex2Index")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final int vertex2Index(){
        return vertex2Index_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int vertex2Index_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QPickLineEvent(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QPickLineEvent(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QPickLineEvent instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.2.2-sources.jar: io/qt/qt3d/render/QPickLineEvent.java <==
package io.qt.qt3d.render;


/**
 * <p>Holds information when a segment of a line is picked</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3drender-qpicklineevent.html">Qt3DRender::QPickLineEvent</a></p>
 */
public class QPickLineEvent extends io.qt.qt3d.render.QPickEvent
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QPickLineEvent.class);
    
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qpicklineevent.html#QPickLineEvent">Qt3DRender::QPickLineEvent::QPickLineEvent()</a></p>
     */
    public QPickLineEvent(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QPickLineEvent instance);
    
    public QPickLineEvent(io.qt.core.QPointF position, io.qt.gui.QVector3D worldIntersection, io.qt.gui.QVector3D localIntersection, float distance, int edgeIndex, int vertex1Index, int vertex2Index, io.qt.qt3d.render.QPickEvent.Buttons button, int buttons, int modifiers){
        super((QPrivateConstructor)null);
        initialize_native(this, position, worldIntersection, localIntersection, distance, edgeIndex, vertex1Index, vertex2Index, button, buttons, modifiers);
    }
    
    private native static void initialize_native(QPickLineEvent instance, io.qt.core.QPointF position, io.qt.gui.QVector3D worldIntersection, io.qt.gui.QVector3D localIntersection, float distance, int edgeIndex, int vertex1Index, int vertex2Index, io.qt.qt3d.render.QPickEvent.Buttons button, int buttons, int modifiers);
    
    /**
     * <p>QPickLineEvent::edgeIndex Returns the index of the picked edge</p>
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qpicklineevent.html#edgeIndex">Qt3DRender::QPickLineEvent::edgeIndex()const</a></p>
     */
    @io.qt.QtPropertyReader(name="edgeIndex")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final int edgeIndex(){
        return edgeIndex_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int edgeIndex_native_constfct(long __this__nativeId);
    
    /**
     * <p>QPickLineEvent::vertex1Index Returns the index of the first point of the picked edge</p>
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qpicklineevent.html#vertex1Index">Qt3DRender::QPickLineEvent::vertex1Index()const</a></p>
     */
    @io.qt.QtPropertyReader(name="vertex1Index")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final int vertex1Index(){
        return vertex1Index_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int vertex1Index_native_constfct(long __this__nativeId);
    
    /**
     * <p>QPickLineEvent::vertex2Index Returns the index of the second point of the picked triangle</p>
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qpicklineevent.html#vertex2Index">Qt3DRender::QPickLineEvent::vertex2Index()const</a></p>
     */
    @io.qt.QtPropertyReader(name="vertex2Index")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final int vertex2Index(){
        return vertex2Index_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int vertex2Index_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QPickLineEvent(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QPickLineEvent(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QPickLineEvent instance, QDeclarativeConstructor constructor);
    
}
